@@ -92,15 +92,17 @@ class OWASP(SCAScanTool):
         component_list = {}
         issue_list = []
         for dependency in dc_report['dependencies']:
+            # only has "packages", then we can tell it is matched
+            # only accept maven package
             if "packages" in dependency:
-                package_id = dependency['packages'][0]['id']
+                package_id = dependency['packages'][-1]['id']
+                if not package_id.startswith("pkg:maven"):
+                    continue
                 group_id, artifact_id, version = resolve_package_id(package_id)
             else:
-                artifact_id = dependency['fileName'].strip()
-                group_id = artifact_id
-                version = 'N.A.'
-            component_report_lib = f'{artifact_id} {group_id}'
-            issue_report_lib = f'{group_id} {artifact_id}'
+                continue
+            component_report_lib = f'{group_id}:{artifact_id}'
+            issue_report_lib = f'{group_id}:{artifact_id}'
             tmp_component = ComponentReport(component_report_lib, version)
             if 'sha256' in dependency:
                 sha256 = dependency['sha256']
@@ -117,8 +119,10 @@ class OWASP(SCAScanTool):
                 for relatDep in dependency['relatedDependencies']:
                     if "packageIds" in relatDep:
                         package_id = relatDep['packageIds'][0]['id']
+                        if not package_id.startswith("pkg:maven"):
+                            continue
                         group_id, artifact_id, version = resolve_package_id(package_id)
-                        tmp_component = ComponentReport(f'{artifact_id} {group_id}', version)
+                        tmp_component = ComponentReport(f'{artifact_id}:{group_id}', version)
                         if 'sha256' in relatDep:
                             sha256 = relatDep['sha256']
                         else:
