@@ -110,6 +110,8 @@ class Scantist(SCAScanTool):
         return self.get_report_from_cmd(scan_feedback)
 
     def get_report_from_cmd(self, scan_feedback=None):
+        if not scan_feedback:
+            raise AttributeError("currently, cannot use skip scan for scantist.")
         # get scan id from output
         component_list_report = re.search(
             r"Saving component report to (.+)\n", scan_feedback
@@ -121,6 +123,8 @@ class Scantist(SCAScanTool):
             raise Exception(f"component report not find in {component_list_report}")
         if not os.path.isfile(issue_list_report):
             raise Exception(f"issue report not find in {issue_list_report}")
+        logger.info(f"issue report found in {issue_list_report}")
+        logger.info(f"component report found in {component_list_report}")
 
         total_component_dict = {}
         total_issue_dict = {}
@@ -131,15 +135,15 @@ class Scantist(SCAScanTool):
             match_status = component['Status']
             if match_status == "un-matched":
                 continue
-            scope = component['Scope']
+            scope = component['Scope'].split(' ')[0]
             language = component['Language']
             library_name = component['Library']
             library_version = component['Library Version']
             # a true dependency must have scope, filter all virtual nodes and unwanted scopes
-            if scope.lower() in ['-', 'test', 'system']:
+            if scope.lower() in ['-', 'test', 'system', 'provided']:
                 continue
             # filter all other deps such as js
-            if language.lower() not in ['java', '-']:
+            if language.lower() not in ['java']:
                 continue
             tmp = ComponentReport(library_name, library_version)
             total_component_dict[tmp.get_hash()] = tmp
@@ -147,6 +151,17 @@ class Scantist(SCAScanTool):
         issue_report = open(issue_list_report, 'r')
         issue_reader = csv.DictReader(issue_report)
         for issue in issue_reader:
+            match_status = component['Status']
+            if match_status == "un-matched":
+                continue
+            scope = component['Scope']
+            language = component['Language']
+            # a true dependency must have scope, filter all virtual nodes and unwanted scopes
+            if scope.lower() in ['-', 'test', 'system', 'provided']:
+                continue
+            # filter all other deps such as js
+            if language.lower() not in ['java']:
+                continue
             library_name = issue['Library']
             library_version = issue['Library Version']
             public_id = issue['Public ID']
