@@ -240,17 +240,10 @@ class Whitesource(SCAScanTool):
         component_list = []
         for library in json_data["libraries"]:
             l_type = library["type"]
-            if l_type == "MAVEN_ARTIFACT" \
-                    or (library['groupId'] and library['artifactId'] != library['groupId']) \
-                    or library['name'].endswith(".jar"):
-                l_name = f"{library['artifactId']} {library['groupId']}"
+            if l_type == "MAVEN_ARTIFACT":
+                l_name = f"{library['groupId']}:{library['artifactId']}"
             else:
-                l_name = library["groupId"]
-                # currently only collect java deps
-                continue
-            if l_name == "":
-                l_name = library["name"].rsplit('-',1)[0]
-            l_name = l_name.strip()
+               continue
             l_version = library["version"]
             tmp_component = ComponentReport(l_name.strip(), l_version)
             if library.__contains__("outdatedModel"):
@@ -292,16 +285,10 @@ class Whitesource(SCAScanTool):
         issue_list = []
         for library in json_data["libraries"]:
             l_type = library["type"]
-            if l_type == "MAVEN_ARTIFACT" \
-                    or (library['groupId'] and library['artifactId'] != library['groupId'])\
-                    or library['name'].endswith(".jar"):
-                l_name = f"{library['artifactId']} {library['groupId']}"
+            if l_type == "MAVEN_ARTIFACT":
+                l_name = f"{library['groupId']}:{library['artifactId']}"
             else:
-                l_name = library["groupId"]
-                # currently only collect java deps
                 continue
-            if l_name == "":
-                l_name = library["name"].rsplit('-', 1)[0]
             l_version = library["version"]
             tmp_issue_list = self.get_issues_by_vulnerability(
                 library, l_name, l_version
