@@ -26,9 +26,12 @@ def trigger_scan(argv):
     param_manager.put_param("output", argv.output)
     param_manager.put_param("options", argv.options)
     param_manager.put_param("image_name_tag", argv.url)
+    param_manager.put_param("skip_scan", argv.skip_scan)
 
     sca_obj = sca_factory(param_manager)
-    scan_feedback = sca_obj.scan_project()
+    scan_feedback = None
+    if argv.skip_scan == "false":
+        scan_feedback = sca_obj.scan_project()
     sca_obj.get_result(scan_feedback)
 
 
@@ -61,6 +64,9 @@ def main():
     parser.add_argument(
         "-options", type=str, default=""
     )
+    parser.add_argument(
+        "-skip_scan", type=str, default="false"
+    )
 
     if len(sys.argv) == 1:
         parser.print_help(sys.stderr)
