@@ -5,6 +5,8 @@ import traceback
 import os
 import zipfile
 
+from karby.util.models import ComponentReport, IssueReport
+
 
 def github_url_analyzer(github_url):
     """
@@ -46,18 +48,20 @@ def check_mvn_proj_info(project_url):
     cmd = f"cd {project_url} && mvn -q" \
           " -Dexec.executable=echo" \
           " -Dexec.args='${project.groupId} ${project.artifactId} ${project.version}'" \
-          " --non-recursive exec:exec 2>/dev/null"
+          " exec:exec 2>/dev/null"
     result = exec_command(cmd)
+    gav_list = []
     if result.get("code") != 0:
         raise EnvironmentError("check_mvn_proj_info failed.")
     else:
         if 'output' in result:
             output = result['output'].decode()
-            group, artifact, version = output.split(' ')
-            return (group, artifact, version)
+            for line in output.split(os.linesep):
+                group, artifact, version = line.split(' ')
+                gav_list.append((group, artifact, version))
         else:
             raise RuntimeError("getting maven project info failed")
-
+    return gav_list
 
 def project_dir_analyzer(project_dir: str):
     if os.path.isdir(project_dir):
@@ -74,20 +78,7 @@ def name_tag_analyzer(nameTag: str):
         raise AttributeError("given url is not a project dir")
 
 def write_issue_report(info_list, report_name, output_dir):
-    field_names = [
-        "Library",
-        "Library Version",
-        "Public ID",
-        "Score",
-        "Description",
-        "File Path",
-        "Patched Version",
-        "Latest Component Version",
-        "Issue Source",
-        "Issue Type",
-        "Priority",
-        "Comments",
-    ]
+    field_names = IssueReport.field_names
     try:
         if not os.path.exists(output_dir):
             os.mkdir(output_dir)
@@ -101,18 +92,7 @@ def write_issue_report(info_list, report_name, output_dir):
 
 
 def write_component_report(info_list, report_name, output_dir):
-    field_names = [
-        "Library",
-        "Depth",
-        "Version",
-        "Latest Version",
-        "File Path",
-        "Vulnerabilities",
-        "License",
-        "Popularity",
-        "Recommended upgrade",
-        "Vulnerability List",
-    ]
+    field_names = ComponentReport.field_names
     try:
         if not os.path.exists(output_dir):
             os.mkdir(output_dir)
