@@ -1,26 +1,24 @@
-class ComponentReport:
-    def __init__(self, library, version):
-        self.field_names = [
+field_names = [
             "Library",
-            "Depth",
-            "Version",
-            "Latest Version",
+            "Scope",
+            "Library Version",
             "File Path",
             "Vulnerabilities",
             "License",
-            "Popularity",
+            "Language",
             "Recommended upgrade",
             "Vulnerability List",
         ]
+class ComponentReport:
+    def __init__(self, library, version, scope='-'):
         self.info = {
             "Library": library,
-            "Depth": "",
-            "Version": version,
-            "Latest Version": "",
+            "Scope": scope,
+            "Library Version": version,
             "File Path": "",
             "Vulnerabilities": "",
             "License": "",
-            "Popularity": "",
+            "Language": "",
             "Recommended upgrade": "",
             "Vulnerability List": [],
         }
@@ -36,4 +34,4 @@ class ComponentReport:
         return self.info["Vulnerability List"]
 
     def get_hash(self):
-        return self.info['Library'] + " " + self.info['Version']
\ No newline at end of file
+        return self.info['Library'] + " " + self.info['Library Version']
\ No newline at end of file
