@@ -1,34 +1,33 @@
-class IssueReport:
-    def __init__(self, library, library_version, public_id):
-        self.field_names = [
+
+field_names = [
             "Library",
             "Library Version",
             "Public ID",
+            "Scope",
             "Score",
-            "Description",
             "File Path",
             "Patched Version",
             "Latest Component Version",
             "Issue Source",
-            "Issue Type",
-            "Priority",
-            "Comments",
         ]
+
+class IssueReport:
+    def __init__(self, library, library_version, public_id, scope="-"):
         self.info = {
             "Library": library,
             "Library Version": library_version,
             "Public ID": public_id,
+            "Scope": scope,
             "Score": "",
-            "Description": "",
             "File Path": "",
             "Patched Version": "",
             "Latest Component Version": "",
             "Issue Source": "",
-            "Issue Type": "",
-            "Priority": "",
-            "Comments": "",
         }
 
+    def get_field(self):
+        return self.field_names
+
     def set_field(self, key, value):
         if self.info.__contains__(key):
             self.info[key] = value
